import './App.css';
import logo from './img/m-logo.png'
import mount1 from './img/mount1.jpg'
import mount2 from './img/mount2.jpg'
import mount3 from './img/mount3.jpg'


const Logo = () =>
  <div className="logo">
    <img src={logo} alt="logo"/>
    <div className="header__title">
      <h1>PEAKS</h1>
      <h2>hiking club</h2>
    </div>
  </div>

const Header = () =>
  <div className="header">
    <Logo/>
    <button className="joinBtn">Join us</button>
    <a href="#">Already has an account</a>
  </div>

const Content = ({children}) =>
  <div className="content">
    {children}
  </div>

const PlaceCard = ({url='#', img='#', title='Card', children}) =>
  <div className="placeCard">
    <div className="placeCard__wrapper">
      <div className="imgWrapper"><img src={img}/></div>
      <div>
        <h2>{title}</h2>
        <p>{children}</p>
        <a href={url} target="_blank">Learn more...</a>
      </div>
    </div>
  </div>

const Banner = () =>
  <div className="banner">
    <div className="banner__wrapper">
      <div>
        <h2>Ready to <span className="highlight">start</span> your adventure?</h2>
        <p>Start your journey for new impressions</p>
      </div>
      <button className="joinBtn">Join us</button>
    </div>
  </div>

const Footer = () =>
  <footer className="footer">
    <Logo/>
    <p className="footer__text">
      We create content and curate adventures for people looking for a truly authentic encounter in the great
      outdoors.
    </p>
    <p className="footer__copyright">
      &copy; 2021 by PEAKS hiking club
    </p>
  </footer>

function App() {
    return (
      <div className="App">
        <Header/>
        <h1 className="headline2">Join one of our <span className="highlight">awesome</span> hikes!</h1>
        <p className="description">
          Let us show you the hidden gems and adventurous trails our place has to offer.
          Our mountains are much less explored than their Slovakian,
          Polish or even Romanian counterparts. Add to that maps in Cyrillic and barely marked routes,
          and you are up for a true adventure!
        </p>
        <Content>
            <h2 className="headline2">Welcome to <span className="highlight">adventure!</span></h2>
            <PlaceCard 
              title="Tranquility cracks"
              url="https://secretcapetown.co.za/tranquility-cracks-table-mountain/"
              img={mount1}>
                We go on a visually stimulating adventure through some of most scenic and popular ravines.
                The incredibly impressive Tranquility Cracks shows off a complex series of paths, tunnel ways and
                awe-inspiring views.
            </PlaceCard>
            <PlaceCard 
              title="Skeleton gorge"
              url="https://www.hikeaddicts.com/our-hikes/skeleton-gorge/"
              img={mount2}>
                Making our way through Skeleton Gorge's ravine, along the Smuts Track.
                Navigating through a series of ladders and mossy river boulders, we arrive at one of the famous and
                historical white beach sand dams atop the summit.
            </PlaceCard>
            <PlaceCard 
              title="Devils peak"
              url="https://en.wikipedia.org/wiki/Devil%27s_Peak_(Cape_Town)"
              img={mount3}>
                We commence at the base of the Tafelberg start point walking the contour.
                With unique views and possibly the best vantage point to make out the entire Lion, lying below Table
                Mountain.
            </PlaceCard>
        </Content>
        <Banner/>
        <Footer/>
      </div>
    )
}

export default App;
